@@ -9,7 +9,7 @@ class MarpaX::Languages::M4::Impl::Macros {
     use MarpaX::Languages::M4::Type::Macro -all;
     use MooX::HandlesVia;
 
-    our $VERSION = '0.010'; # VERSION
+    our $VERSION = '0.011'; # VERSION
 
     our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -23,7 +23,8 @@ class MarpaX::Languages::M4::Impl::Macros {
             macros_push     => 'push',
             macros_pop      => 'pop',
             macros_set      => 'set',
-            macros_get      => 'get'
+            macros_get      => 'get',
+            macros_elements => 'elements'
         }
     );
 
@@ -44,7 +45,7 @@ MarpaX::Languages::M4::Impl::Macros - M4 Macro list generic implementation
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
