@@ -6,7 +6,7 @@ use Moops;
 
 role MarpaX::Languages::M4::Role::Impl {
 
-    our $VERSION = '0.010'; # VERSION
+    our $VERSION = '0.011'; # VERSION
 
     our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -32,6 +32,8 @@ role MarpaX::Languages::M4::Role::Impl {
     requires 'impl_macroExecute';
     requires 'impl_macroCallId';
     requires 'impl_debugfile';
+    requires 'impl_reloadState';
+    requires 'impl_freezeState';
 
     with 'MarpaX::Languages::M4::Role::Builtin';
     with 'MarpaX::Languages::M4::Role::Logger';
@@ -52,7 +54,7 @@ MarpaX::Languages::M4::Role::Impl - M4 implementation role
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
